#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 random-bytestring
version:              0.1.4
visibility:           public
id:                   random-bytestring-0.1.4-5mIhaFyOSWv31MdtJQAeVA
key:                  random-bytestring-0.1.4-5mIhaFyOSWv31MdtJQAeVA
license:              MIT
copyright:            Copyright (c) 2017-2021 Lars Kuhtz <lakuhtz@gmail.com>
maintainer:           Lars Kuhtz <lakuhtz@gmail.com>
author:               Lars Kuhtz <lakuhtz@gmail.com>
homepage:             https://www.github.com/larskuhtz/random-bytestring
synopsis:             Efficient generation of random bytestrings
description:
    __This package is deprecated__. Please, use
    '\''genByteString'\'' from the [random
    package (version >=1.2)](https://hackage.haskell.org/package/random) instead.

    Efficient generation of random bytestrings. The implementation
    populates uninitialized memory with uniformily distributed random
    64 bit words (and 8 bit words for remaining bytes at the end of
    the bytestring).

    Random words are generated using the PRNG from
    the [mwc-random](https://hackage.haskell.org/package/mwc-random) package
    or the [pcg-random](https://hackage.haskell.org/package/pcg-random)
    package. It is also possible to use a custom PRNG by providing
    an instance for the '\''RandomWords'\'' type class and using the function
    '\''generate'\'' from the module "Data.ByteString.Random.Internal".

    The generated byte strings are suitable for statistical
    applications. They are /not/ suitable for cryptographic
    applications.

    ![benchmarks](https://hackage.haskell.org/package/random-bytestring-0.1.3.2/src/benchmarks.png)

    ![detailed benchmarks](https://hackage.haskell.org/package/random-bytestring-0.1.3.2/src/benchmarks-details.png)

category:             System
abi:                  f82357d361841fc436e6c4e5c5df60d4
exposed:              True
exposed-modules:
    Data.ByteString.Random Data.ByteString.Random.Internal
    Data.ByteString.Random.MWC Data.ByteString.Random.PCG

import-dirs:          /usr/lib/ghc-9.6.6/site-local/random-bytestring-0.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/random-bytestring-0.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/random-bytestring-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-bytestring
hs-libraries:         HSrandom-bytestring-0.1.4-5mIhaFyOSWv31MdtJQAeVA
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    mwc-random-0.15.3.0-JgIGx1ip5srC1VU2syIxyc
    pcg-random-0.1.4.0-JYdju9pmC6A4W2q4V5TgXz

haddock-interfaces:
    /usr/share/doc/haskell-random-bytestring/html/random-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-random-bytestring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

